@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION = '2.37';
+$Map::Tube::VERSION = '2.38';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube - Core library as Role (Moo) to process map data.
 
 =head1 VERSION
 
-Version 2.37
+Version 2.38
 
 =cut
 
@@ -19,7 +19,6 @@ use Map::Tube::Node;
 use Map::Tube::Table;
 use Map::Tube::Route;
 use Map::Tube::Exception;
-use Encode qw(decode_utf8);
 use Map::Tube::Error qw(:constants);
 
 use Moo::Role;
@@ -63,7 +62,6 @@ has nodes      => (is => 'rw');
 has tables     => (is => 'rw');
 has routes     => (is => 'rw');
 has name_to_id => (is => 'rw');
-has utf8       => (is => 'ro', default => sub { 1 });
 
 sub BUILD {
     my ($self) = @_;
@@ -85,11 +83,6 @@ name or encoding the response is no longer required.
 sub get_shortest_route {
     my ($self, $from, $to) = @_;
 
-    if ($self->utf8) {
-        $from = decode_utf8($from);
-        $to   = decode_utf8($to);
-    }
-
     ($from, $to) =
         $self->_validate_input('get_shortest_route', $from, $to);
 
@@ -136,11 +129,6 @@ However for comparatively smaller map, like below,it is happy to give all routes
 sub get_all_routes {
     my ($self, $from, $to) = @_;
 
-    if ($self->utf8) {
-        $from = decode_utf8($from);
-        $to   = decode_utf8($to);
-    }
-
     ($from, $to) =
         $self->_validate_input('get_all_routes', $from, $to);
 
@@ -155,7 +143,6 @@ sub init_map {
     my $xml    = XMLin($self->xml, KeyAttr => 'stations', ForceArray => 0);
 
     foreach my $station (@{$xml->{stations}->{station}}) {
-        $station->{utf8} = $self->utf8;
         my $node = Map::Tube::Node->new($station);
         my $id   = $node->id;
         my $name = $node->name;
