@@ -1,6 +1,6 @@
 package Map::Tube::Node;
 
-$Map::Tube::Node::VERSION = '2.37';
+$Map::Tube::Node::VERSION = '2.38';
 
 =head1 NAME
 
@@ -8,13 +8,12 @@ Map::Tube::Node - Class to represent the node in the map.
 
 =head1 VERSION
 
-Version 2.37
+Version 2.38
 
 =cut
 
 use 5.006;
 use Data::Dumper;
-use Encode qw(encode_utf8);
 
 use Moo;
 use namespace::clean;
@@ -25,17 +24,11 @@ has id   => (is => 'ro', required => 1);
 has name => (is => 'ro', required => 1);
 has link => (is => 'ro', required => 1);
 has line => (is => 'ro', required => 1);
-has utf8 => (is => 'ro', required => 1);
 
 sub as_string {
     my ($self) = @_;
 
-    my $node = sprintf("%s (%s)", $self->name, $self->line);
-    ($self->utf8)
-    ?
-    (return encode_utf8($node))
-    :
-    (return $node);
+    return sprintf("%s (%s)", $self->name, $self->line);
 }
 
 =head1 METHODS
@@ -56,10 +49,6 @@ Returns the linked station id as defined in the map data.
 
 Returns the line(s) the station linked to as defined in the map data.
 
-=head2 utf8()
-
-Returns true/false (0/1) whether station name/line should be utf8 encoded.
-
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
